==> open-xchange-guard_2.4.2.orig.tar.bz2: open-xchange-guard-2.4.2/com.openexchange.guard.inputvalidation/src/com/openexchange/guard/inputvalidation/AbstractInputValidator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.inputvalidation;

import com.openexchange.exception.OXException;
import com.openexchange.guard.inputvalidation.exceptions.InputValidationExceptionCodes;

/**
 * {@link AbstractInputValidator} validates a given input
 *
 * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
 * @since v2.4.2
 */
public abstract class AbstractInputValidator<T> implements InputValidator<T> {

    /*
     * (non-Javadoc)
     * 
     * @see com.openexchange.guard.inputvalidation.InputValidator#assertIsValid(java.lang.Object)
     */
    @Override
    public void assertIsValid(T value) throws OXException {
        if (!isValid(value)) {
            throw InputValidationExceptionCodes.INVALID_INPUT_ERROR.create();
        }
    }
}

==> open-xchange-guard_2.10.5.orig.tar.bz2: open-xchange-guard-2.10.5/com.openexchange.guard.inputvalidation/src/com/openexchange/guard/inputvalidation/AbstractInputValidator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.inputvalidation;

import com.openexchange.exception.OXException;
import com.openexchange.guard.inputvalidation.exceptions.InputValidationExceptionCodes;

/**
 * {@link AbstractInputValidator} validates a given input
 *
 * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
 * @since v2.4.2
 */
public abstract class AbstractInputValidator<T> implements InputValidator<T> {

    /* (non-Javadoc)
     * @see com.openexchange.guard.inputvalidation.InputValidator#getValue(java.lang.Object)
     */
    @Override
    public T getInput(T input) {
        return isValid(input) ? input : null;
    }

    /*
     * (non-Javadoc)
     *
     * @see com.openexchange.guard.inputvalidation.InputValidator#assertIsValid(java.lang.Object)
     */
    @Override
    public void assertIsValid(T input) throws OXException {
        assertIsValid(input, "user input");
    }

    /* (non-Javadoc)
     * @see com.openexchange.guard.inputvalidation.InputValidator#assertIsValid(java.lang.Object, java.lang.String)
     */
    @Override
    public void assertIsValid(T input, String inputFieldName) throws OXException {
        if (!isValid(input)) {
            throw InputValidationExceptionCodes.INVALID_INPUT_ERROR.create(inputFieldName);
        }
    }

    /* (non-Javadoc)
     * @see com.openexchange.guard.inputvalidation.InputValidator#assertInput(java.lang.Object)
     */
    @Override
    public T assertInput(T input) throws OXException {
        assertIsValid(input);
        return input;
    }

    /* (non-Javadoc)
     * @see com.openexchange.guard.inputvalidation.InputValidator#assertInput(java.lang.Object, java.lang.String)
     */
    @Override
    public T assertInput(T input, String inputFieldName) throws OXException {
        assertIsValid(input, inputFieldName);
        return input;
    }
}
